==> aws-sdk-cpp-1.11.667-1-x86_64.pkg.tar.zst: usr/include/aws/polly/PollyErrors.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once

#include <aws/core/client/AWSError.h>
#include <aws/core/client/CoreErrors.h>
#include <aws/polly/Polly_EXPORTS.h>

namespace Aws
{
namespace Polly
{
enum class PollyErrors
{
  //From Core//
  //////////////////////////////////////////////////////////////////////////////////////////
  INCOMPLETE_SIGNATURE = 0,
  INTERNAL_FAILURE = 1,
  INVALID_ACTION = 2,
  INVALID_CLIENT_TOKEN_ID = 3,
  INVALID_PARAMETER_COMBINATION = 4,
  INVALID_QUERY_PARAMETER = 5,
  INVALID_PARAMETER_VALUE = 6,
  MISSING_ACTION = 7, // SDK should never allow
  MISSING_AUTHENTICATION_TOKEN = 8, // SDK should never allow
  MISSING_PARAMETER = 9, // SDK should never allow
  OPT_IN_REQUIRED = 10,
  REQUEST_EXPIRED = 11,
  SERVICE_UNAVAILABLE = 12,
  THROTTLING = 13,
  VALIDATION = 14,
  ACCESS_DENIED = 15,
  RESOURCE_NOT_FOUND = 16,
  UNRECOGNIZED_CLIENT = 17,
  MALFORMED_QUERY_STRING = 18,
  SLOW_DOWN = 19,
  REQUEST_TIME_TOO_SKEWED = 20,
  INVALID_SIGNATURE = 21,
  SIGNATURE_DOES_NOT_MATCH = 22,
  INVALID_ACCESS_KEY_ID = 23,
  REQUEST_TIMEOUT = 24,
  NETWORK_CONNECTION = 99,

  UNKNOWN = 100,
  ///////////////////////////////////////////////////////////////////////////////////////////

  ENGINE_NOT_SUPPORTED= static_cast<int>(Aws::Client::CoreErrors::SERVICE_EXTENSION_START_RANGE) + 1,
  INVALID_LEXICON,
  INVALID_NEXT_TOKEN,
  INVALID_S3_BUCKET,
  INVALID_S3_KEY,
  INVALID_SAMPLE_RATE,
  INVALID_SNS_TOPIC_ARN,
  INVALID_SSML,
  INVALID_TASK_ID,
  LANGUAGE_NOT_SUPPORTED,
  LEXICON_NOT_FOUND,
  LEXICON_SIZE_EXCEEDED,
  MARKS_NOT_SUPPORTED_FOR_FORMAT,
  MAX_LEXEME_LENGTH_EXCEEDED,
  MAX_LEXICONS_NUMBER_EXCEEDED,
  SERVICE_FAILURE,
  SSML_MARKS_NOT_SUPPORTED_FOR_TEXT_TYPE,
  SYNTHESIS_TASK_NOT_FOUND,
  TEXT_LENGTH_EXCEEDED,
  UNSUPPORTED_PLS_ALPHABET,
  UNSUPPORTED_PLS_LANGUAGE
};

class AWS_POLLY_API PollyError : public Aws::Client::AWSError<PollyErrors>
{
public:
  PollyError() {}
  PollyError(const Aws::Client::AWSError<Aws::Client::CoreErrors>& rhs) : Aws::Client::AWSError<PollyErrors>(rhs) {}
  PollyError(Aws::Client::AWSError<Aws::Client::CoreErrors>&& rhs) : Aws::Client::AWSError<PollyErrors>(rhs) {}
  PollyError(const Aws::Client::AWSError<PollyErrors>& rhs) : Aws::Client::AWSError<PollyErrors>(rhs) {}
  PollyError(Aws::Client::AWSError<PollyErrors>&& rhs) : Aws::Client::AWSError<PollyErrors>(rhs) {}

  template <typename T>
  T GetModeledError();
};

namespace PollyErrorMapper
{
  AWS_POLLY_API Aws::Client::AWSError<Aws::Client::CoreErrors> GetErrorForName(const char* errorName);
}

} // namespace Polly
} // namespace Aws

==> aws-sdk-cpp-1.11.686-1-x86_64.pkg.tar.zst: usr/include/aws/polly/PollyErrors.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once

#include <aws/core/client/AWSError.h>
#include <aws/core/client/CoreErrors.h>
#include <aws/polly/Polly_EXPORTS.h>

namespace Aws {
namespace Polly {
enum class PollyErrors {
  // From Core//
  //////////////////////////////////////////////////////////////////////////////////////////
  INCOMPLETE_SIGNATURE = 0,
  INTERNAL_FAILURE = 1,
  INVALID_ACTION = 2,
  INVALID_CLIENT_TOKEN_ID = 3,
  INVALID_PARAMETER_COMBINATION = 4,
  INVALID_QUERY_PARAMETER = 5,
  INVALID_PARAMETER_VALUE = 6,
  MISSING_ACTION = 7,                // SDK should never allow
  MISSING_AUTHENTICATION_TOKEN = 8,  // SDK should never allow
  MISSING_PARAMETER = 9,             // SDK should never allow
  OPT_IN_REQUIRED = 10,
  REQUEST_EXPIRED = 11,
  SERVICE_UNAVAILABLE = 12,
  THROTTLING = 13,
  VALIDATION = 14,
  ACCESS_DENIED = 15,
  RESOURCE_NOT_FOUND = 16,
  UNRECOGNIZED_CLIENT = 17,
  MALFORMED_QUERY_STRING = 18,
  SLOW_DOWN = 19,
  REQUEST_TIME_TOO_SKEWED = 20,
  INVALID_SIGNATURE = 21,
  SIGNATURE_DOES_NOT_MATCH = 22,
  INVALID_ACCESS_KEY_ID = 23,
  REQUEST_TIMEOUT = 24,
  NETWORK_CONNECTION = 99,

  UNKNOWN = 100,
  ///////////////////////////////////////////////////////////////////////////////////////////

  ENGINE_NOT_SUPPORTED = static_cast<int>(Aws::Client::CoreErrors::SERVICE_EXTENSION_START_RANGE) + 1,
  INVALID_LEXICON,
  INVALID_NEXT_TOKEN,
  INVALID_S3_BUCKET,
  INVALID_S3_KEY,
  INVALID_SAMPLE_RATE,
  INVALID_SNS_TOPIC_ARN,
  INVALID_SSML,
  INVALID_TASK_ID,
  LANGUAGE_NOT_SUPPORTED,
  LEXICON_NOT_FOUND,
  LEXICON_SIZE_EXCEEDED,
  MARKS_NOT_SUPPORTED_FOR_FORMAT,
  MAX_LEXEME_LENGTH_EXCEEDED,
  MAX_LEXICONS_NUMBER_EXCEEDED,
  SERVICE_FAILURE,
  SSML_MARKS_NOT_SUPPORTED_FOR_TEXT_TYPE,
  SYNTHESIS_TASK_NOT_FOUND,
  TEXT_LENGTH_EXCEEDED,
  UNSUPPORTED_PLS_ALPHABET,
  UNSUPPORTED_PLS_LANGUAGE
};

class AWS_POLLY_API PollyError : public Aws::Client::AWSError<PollyErrors> {
 public:
  PollyError() {}
  PollyError(const Aws::Client::AWSError<Aws::Client::CoreErrors>& rhs) : Aws::Client::AWSError<PollyErrors>(rhs) {}
  PollyError(Aws::Client::AWSError<Aws::Client::CoreErrors>&& rhs) : Aws::Client::AWSError<PollyErrors>(rhs) {}
  PollyError(const Aws::Client::AWSError<PollyErrors>& rhs) : Aws::Client::AWSError<PollyErrors>(rhs) {}
  PollyError(Aws::Client::AWSError<PollyErrors>&& rhs) : Aws::Client::AWSError<PollyErrors>(rhs) {}

  template <typename T>
  T GetModeledError();
};

namespace PollyErrorMapper {
AWS_POLLY_API Aws::Client::AWSError<Aws::Client::CoreErrors> GetErrorForName(const char* errorName);
}

}  // namespace Polly
}  // namespace Aws
